#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_fastener_interfaces.fastener import Fastener
from pycatia.system_interfaces.collection import Collection


class FastenerSet(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     FastenerSet
                | 
                | Interface DELMIAFasteners DELMIAFasteners represent collection of fasteners of
                | both types point and curve.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Fastener)
        self.fastener_set = com_object

    def get_fastener(self, index: int) -> Fastener:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFastener(short index) As Fastener
                | 
                |     Get a specified DELMIAFastener from the collection of Fasteners. The
                |     specification is through the Index or the location of fastener in the list.
                |     Index starts at 1.
                | 
                |     Parameters:
                | 
                |         index
                |             Integer for the index in the list. It is an input parameter.
                |             
                |         opiFastener
                |             Returned instance of DELMIAFastener. It contains the return
                |             DELMIAFastener at the specifed index. It is an output
                |             parameter.

        :param int index:
        :rtype: Fastener
        """
        return Fastener(self.fastener_set.GetFastener(index))

    def __repr__(self):
        return f'FastenerSet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_functional import PSPFunctional
from pycatia.cat_plant_ship_interfaces.psp_spatial import PSPSpatial
from pycatia.system_interfaces.any_object import AnyObject


class PSPPhysical(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspPhysical
                | 
                | Represents the object to access Plant Ship physical object
                | information.
                | Role: To access access Plant Ship physical object information.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_physical = com_object

    def get_functional(self) -> PSPFunctional:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFunctional() As PspFunctional
                | 
                |     Returns the Function object.
                | 
                |     Returns:
                |         Functional object associated with the physical object
                |
                |     Example:
                |
                |          Dim objThisIntf As PspPhysical
                |          Dim objArg1 As PspFunctional
                |           ...
                |          Set objArg1 = objThisIntf.GetFunctional

        :rtype: PSPFunctional
        """
        return PSPFunctional(self.psp_physical.GetFunctional())

    def get_spatial(self) -> PSPSpatial:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSpatial() As PspSpatial
                | 
                |     Returns the Spatial object.
                | 
                |     Returns:
                |         Spatial object associated with the physical object
                |
                |     Example:
                |
                |          Dim objThisIntf As PspPhysical
                |          Dim objArg1 As PspSpatial
                |           ...
                |          Set objArg1 = objThisIntf.GetSpatial

        :rtype: PSPSpatial
        """
        return PSPSpatial(self.psp_physical.GetSpatial())

    def __repr__(self):
        return f'PSPPhysical(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SimulationInitState(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SimulationInitState
                | 
                | Interface used to save/restore the simulation initial state.
                | 
                | Role: This interface is used to save/restore the initial state for objects in
                | the current document.
                | The following code snippet can be used to save the simulation initial state for
                | all the objects in the current document (all attributes). The rootProduct can
                | be any product from the current document.
                | 
                |   Dim iMask
                |   iMask = DNBAllInitStateAttr
                | 
                |   Dim iSimInitState As SimulationInitState
                |   Set iSimInitState = rootProduct.GetTechnologicalObject("SimulationInitState")
                |   iSimInitState.SaveInitialState iMask
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.simulation_init_state = com_object

    def restore_initial_state(self, i_attr_mask: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RestoreInitialState(DNBSimInitStateAttr iAttrMask)
                | 
                |     Restores initial state attributes for all objects in the current document
                |     that have a saved initial state.
                | 
                |     Parameters:
                | 
                |         iAttrMask
                |             Indicates which initial state attributes will be restored
                |
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The restore operation succeeded
                |         E_FAIL
                |             The restore operation failed

        :param int i_attr_mask: enum dnb_sim_init_state_attr
        :rtype: None
        """
        return self.simulation_init_state.RestoreInitialState(i_attr_mask)

    def restore_initial_state_list(self, i_product_lists: tuple, i_attr_mask: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RestoreInitialStateList(CATSafeArrayVariant
                | iProductLists,
                | DNBSimInitStateAttr iAttrMask)
                | 
                |     Restores initial state attributes for the objects in the given
                |     list.
                | 
                |     Parameters:
                | 
                |         iProductLists
                |             Indicates which objects will be used for the restore initial state
                |             operation 
                |         iAttrMask
                |             Indicates which initial state attributes will be restored
                |
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The restore operation succeeded
                |         E_FAIL
                |             The restore operation failed

        :param tuple i_product_lists:
        :param int i_attr_mask: enum dnb_sim_init_state_attr
        :rtype: None
        """
        return self.simulation_init_state.RestoreInitialStateList(i_product_lists, i_attr_mask)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'restore_initial_state_list'
        # # vba_code = """
        # # Public Function restore_initial_state_list(simulation_init_state)
        # #     Dim iProductLists (2)
        # #     simulation_init_state.RestoreInitialStateList iProductLists
        # #     restore_initial_state_list = iProductLists
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def save_initial_state(self, i_attr_mask: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SaveInitialState(DNBSimInitStateAttr iAttrMask)
                | 
                |     Saves initial state attributes for all objects in the current
                |     document.
                | 
                |     Parameters:
                | 
                |         iAttrMask
                |             Indicates which initial state attributes will be saved
                |
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The save operation succeeded
                |         E_FAIL
                |             The save operation failed

        :param int i_attr_mask: enum dnb_sim_init_state_attr
        :rtype: None
        """
        return self.simulation_init_state.SaveInitialState(i_attr_mask)

    def save_initial_state_list(self, i_product_lists: tuple, i_attr_mask: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SaveInitialStateList(CATSafeArrayVariant
                | iProductLists,
                | DNBSimInitStateAttr iAttrMask)
                | 
                |     Saves initial state attributes for the objects in the given
                |     list.
                | 
                |     Parameters:
                | 
                |         iProductLists
                |             Indicates which objects will be used for the save initial state
                |             operation 
                |         iAttrMask
                |             Indicates which initial state attributes will be saved
                |
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The save operation succeeded
                |         E_FAIL
                |             The save operation failed

        :param tuple i_product_lists:
        :param int i_attr_mask: enum dnb_sim_init_state_attr
        :rtype: None
        """
        return self.simulation_init_state.SaveInitialStateList(i_product_lists, i_attr_mask)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'save_initial_state_list'
        # # vba_code = """
        # # Public Function save_initial_state_list(simulation_init_state)
        # #     Dim iProductLists (2)
        # #     simulation_init_state.SaveInitialStateList iProductLists
        # #     save_initial_state_list = iProductLists
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SimulationInitState(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dnb_human_modeling_interfaces.swk_manikin import SWKManikin


class HumanTask(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         HumanTask

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.human_task = com_object

    @property
    def specified_cycle_time(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SpecifiedCycleTime() As double (Read Only)
                | 
                |     returns the time set by the user by set_SpecifiedCycleTime

        :rtype: float
        """

        return self.human_task.SpecifiedCycleTime

    @property
    def specified_joint_speed(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SpecifiedJointSpeed() As double (Read Only)
                | 
                |     returns the speed set by the user by set_SpecifiedJointSpeed

        :rtype: float
        """

        return self.human_task.SpecifiedJointSpeed

    @property
    def worker_resource(self) -> SWKManikin:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WorkerResource() As SWKManikin (Read Only)
                | 
                |     Returns the Worker-Resource associated with this
                |     worker-activity.
                | 
                |     Returns:
                |         oManikin

        :rtype: SWKManikin
        """

        return SWKManikin(self.human_task.WorkerResource)

    def set_specified_cycle_time(self, time: float, i_override_child_act_simulation_time: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_SpecifiedCycleTime(double time,
                | long iOverrideChildActSimulationTime)
                | 
                |     sets the time on the specified task iOverrideChildActSimulationTime: this
                |     should be set equal to zero when no child act overriding is required

        :param float time:
        :param int i_override_child_act_simulation_time:
        :rtype: None
        """
        return self.human_task.set_SpecifiedCycleTime(time, i_override_child_act_simulation_time)

    def set_specified_joint_speed(self, speed: float, i_override_child_joint_speed: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_SpecifiedJointSpeed(double speed,
                | long iOverrideChildJointSpeed)
                | 
                |     sets the joint speed on the specified task(speed should be between 0.0 to
                |     1.0) iOverrideChildJointSpeed: this should be set equal to zero when no child
                |     act overriding is required

        :param float speed:
        :param int i_override_child_joint_speed:
        :rtype: None
        """
        return self.human_task.set_SpecifiedJointSpeed(speed, i_override_child_joint_speed)

    def __repr__(self):
        return f'HumanTask(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_display_group import ABQDisplayGroup
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQDisplayGroups(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQDisplayGroups
                | 
                | The collection of display groups under the abaqus analysis
                | case
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQDisplayGroup)
        self.abq_display_groups = com_object

    def item(self, i_index: cat_variant) -> ABQDisplayGroup:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQDisplayGroup
                | 
                |     Returns an display group using its index or its name from the
                |     ABQDisplayGroups collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the display group to retrieve from the
                |             collection of display groups. If the index is a number, it specifies the rank
                |             of the display group in the collection. The index of the first display group in
                |             the collection is 1, and the index of the last display group is Count. If the
                |             index is a string, it specifies the name you assigned to the display group
                |             using the CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified ABQDisplayGroup.

        :param cat_variant i_index:
        :rtype: ABQDisplayGroup
        """
        return ABQDisplayGroup(self.abq_display_groups.Item(i_index))

    def __repr__(self):
        return f'ABQDisplayGroups(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class Viewpoint2D(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Viewpoint2D
                | 
                | Represents the 2D viewpoint.
                | The 2D viewpoint is the object that stores data which defines how your objects
                | are seen to enable their display by a 2D viewer. This data includes namely the
                | origin of the scene, that is the center of the displayed area, and the zoom
                | factor.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.viewpoint_2d = com_object

    @property
    def zoom(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Zoom() As double
                | 
                |     Returns or sets the zoom factor associated with the
                |     viewpoint.
                | 
                |     Example:
                |         This example retrieves in ZoomFactor the zoom factor associated with
                |         the NiceViewpoint viewpoint, tests if it is less than 1, and if so, sets it to
                |         one and applies it to the viewpoint.
                | 
                |          ZoomFactor = NiceViewpoint.Zoom
                |          If ZoomFactor < 1 Then
                |           ZoomFactor = 1
                |           NiceViewpoint.Zoom(ZoomFactor)
                |          End If

        :rtype: float
        """

        return self.viewpoint_2d.Zoom

    @zoom.setter
    def zoom(self, value: float):
        """
        :param float value:
        """

        self.viewpoint_2d.Zoom = value

    def get_origin(self, o_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Gets the coordinates of the origin of the viewpoint.
                | 
                |     Example:
                |         This example Gets the origin of the NiceViewpoint
                |         viewpoint.
                | 
                |          Dim origin(1)
                |          NiceViewpoint.GetOrigin origin

        :param tuple o_origin:
        :rtype: None
        """
        return self.viewpoint_2d.GetOrigin(o_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_origin'
        # # vba_code = """
        # # Public Function get_origin(viewpoint_2d)
        # #     Dim oOrigin (2)
        # #     viewpoint_2d.GetOrigin oOrigin
        # #     get_origin = oOrigin
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_origin(self, o_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Sets the coordinates of the origin of the viewpoint.
                | 
                |     Example:
                |         This example sets the origin of the NiceViewpoint viewpoint to the
                |         point with coordinates (5, 8).
                | 
                |          NiceViewpoint.PutOrigin Array(5, 8)

        :param tuple o_origin:
        :rtype: None
        """
        return self.viewpoint_2d.PutOrigin(o_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_origin'
        # # vba_code = """
        # # Public Function put_origin(viewpoint_2d)
        # #     Dim oOrigin (2)
        # #     viewpoint_2d.PutOrigin oOrigin
        # #     put_origin = oOrigin
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Viewpoint2D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_tool_motion import ManufacturingToolMotion
from pycatia.system_interfaces.collection import Collection


class MFGToolMotions(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     MfgToolMotions
                | 
                | The collection of MfgToolMotions related to the Manufacturing Document
                | .
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ManufacturingToolMotion)
        self.mfg_tool_motions = com_object

    def add(self, i_real_obj: ManufacturingToolMotion) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Add(ManufacturingToolMotion iRealObj)
                | 
                |     This method adds the specified CATIAManufacturingToolMotion in the current
                |     list CATIAMfgToolMotions.
                | 
                |     Example:
                |         The following example adds in CATIAMfgToolMotions ListToolMotions the
                |         CATIAManufacturingToolMotion ThisToolMotion
                | 
                |          ListToolMotions.Add(ThisToolMotion)

        :param ManufacturingToolMotion i_real_obj:
        :rtype: None
        """
        return self.mfg_tool_motions.Add(i_real_obj.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add'
        # # vba_code = """
        # # Public Function add(mfg_tool_motions)
        # #     Dim iRealObj (2)
        # #     mfg_tool_motions.Add iRealObj
        # #     add = iRealObj
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_element(self, i_index: int) -> ManufacturingToolMotion:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetElement(long iIndex) As ManufacturingToolMotion
                | 
                |     This method return the specified CATIAManufacturingToolMotion in the
                |     current list CATIAMfgToolMotions.
                | 
                |     Example:
                |         The following example return the CATIAManufacturingToolMotion
                |         ThisToolMotion in CATIAMfgToolMotions ListToolMotions in position
                |         NumPos:
                | 
                |          Set ThisToolMotion = ListToolMotions.GetElement(Numpos)

        :param int i_index:
        :rtype: ManufacturingToolMotion
        """
        return ManufacturingToolMotion(self.mfg_tool_motions.GetElement(i_index))

    def __repr__(self):
        return f'MfgToolMotions(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.system_service import SystemService


class Conflict(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Conflict
                | 
                | Represents the Conflict object.
                | 
                | One Conflict object exists for each couple of products that are
                | colliding.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.conflict = com_object

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Comment() As CATBSTR
                | 
                |     Returns or sets a comment on the conflict.
                | 
                |     Example:
                | 
                |              The first example gets the comment of NewConflict
                |              Conflict.
                |
                |             Dim aComment As String
                |             aComment = NewConflict.Comment
                |
                |                 The second example sets a comment on the NewConflict
                |                 Conflict.
                |
                |                 NewConflict.Comment = "OK : plastic part"

        :rtype: str
        """

        return self.conflict.Comment

    @comment.setter
    def comment(self, value: str):
        """
        :param str value:
        """

        self.conflict.Comment = value

    @property
    def comparison_info(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ComparisonInfo() As CatConflictComparison (Read
                | Only)
                | 
                |     Returns the information on the comparison between the conflict and the
                |     previous one.
                | 
                |     Example:
                | 
                |              This example retrieves the comparison information of the
                |              NewConflict Conflict.
                |
                |             Dim anInfo As CatConflictComparison
                |             anInfo = NewConflict.ComparisonInfo

        :return: enum cat_conflict_comparison
        :rtype: int
        """

        return self.conflict.ComparisonInfo

    @property
    def first_product(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstProduct() As Product (Read Only)
                | 
                |     Returns the first product involved in the conflict.
                | 
                |     Example:
                | 
                |              This example retrieves the first product involved in the
                |              NewConflict Conflict.
                |
                |             Dim aProduct As Product
                |             Set aProduct = NewConflict.FirstProduct

        :rtype: Product
        """

        return Product(self.conflict.FirstProduct)

    @property
    def second_product(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondProduct() As Product (Read Only)
                | 
                |     Returns the second product involved in the conflict.
                | 
                |     Example:
                | 
                |              This example retrieves the second product involved in the
                |              NewConflict Conflict.
                |
                |             Dim aProduct As Product
                |             Set aProduct = NewConflict.SecondProduct

        :rtype: Product
        """

        return Product(self.conflict.SecondProduct)

    @property
    def status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Status() As CatConflictStatus
                | 
                |     Returns or sets the status of the conflict.
                | 
                |     Example:
                | 
                |              The first example gets the status of NewConflict
                |              Conflict.
                |
                |             Dim aStatus As CatConflictStatus
                |             aStatus = NewConflict.Status
                |
                |                 The second example sets the status of NewConflict
                |                 Conflict.
                |
                |                 NewConflict.Status = CatConflictStatusIrrelevant

        :return: enum cat_conflict_status
        :rtype: int
        """

        return self.conflict.Status

    @status.setter
    def status(self, value: int):
        """
        :param int value: enum cat_conflict_status
        """

        self.conflict.Status = value

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Type() As CatConflictType (Read Only)
                | 
                |     Returns the type of the conflict.
                | 
                |     Example:
                | 
                |              This example retrieves the type of the NewConflict
                |              Conflict.
                |
                |             Dim conflictType As CatConflictType
                |             conflictType = NewConflict.Type

        :return: enum cat_conflict_type
        :rtype: int
        """

        return self.conflict.Type

    @property
    def value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Value() As double (Read Only)
                | 
                |     Returns the conflict value.
                | 
                |     This value is the penetration lengh in case of a clash or the minimum
                |     distance in case of clearance violation.
                | 
                |     Example:
                | 
                |              This example retrieves the value of the NewConflict
                |              Conflict.
                |
                |             Dim conflictValue As double
                |             conflictValue = NewConflict.Value

        :rtype: float
        """

        return self.conflict.Value

    def get_first_point_coordinates(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetFirstPointCoordinates(CATSafeArrayVariant
                | oCoordinates)
                | 
                |     Retrieves the coordinates of the point on the first product which realizes
                |     the penetration or minimum distance.
                | 
                |     Parameters:
                | 
                |         oCoordinates
                |             The coordinates of the point
                | 
                |                 oCoordinates(0) is the X coordinate
                |                 oCoordinates(1) is the Y coordinate
                |                 oCoordinates(2) is the Z coordinate 
                | 
                |     Example:
                | 
                |              This example retrieves the first product involved in the
                |              NewConflict Conflict.
                |
                |             Dim Coordinates (2)
                |             NewConflict.GetFirstPointCoordinates Coordinates

        :rtype: tuple
        """

        vba_function_name = 'get_first_point_coordinates'
        vba_code = """
        Public Function get_first_point_coordinates(conflict)
            Dim oCoordinates(2)
            conflict.GetFirstPointCoordinates oCoordinates
            get_first_point_coordinates = oCoordinates
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_second_point_coordinates(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetSecondPointCoordinates(CATSafeArrayVariant
                | oCoordinates)
                | 
                |     Retrieves the coordinates of the point on the second product which realizes
                |     the penetration or minimum distance.
                | 
                |     Parameters:
                | 
                |         oCoordinates
                |             The coordinates of the point
                | 
                |                 oCoordinates(0) is the X coordinate
                |                 oCoordinates(1) is the Y coordinate
                |                 oCoordinates(2) is the Z coordinate 
                | 
                |     Example:
                | 
                |              This example retrieves the coordinates in the NewConflict
                |              Conflict.
                |
                |             Dim Coordinates (2)
                |             NewConflict.GetSecondPointCoordinates Coordinates

        :rtype: tuple
        """

        vba_function_name = 'get_second_point_coordinates'
        vba_code = """
        Public Function get_second_point_coordinates(conflict)
            Dim oCoordinates (2)
            conflict.GetSecondPointCoordinates oCoordinates
            get_second_point_coordinates = oCoordinates
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Conflict(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.eno_cd5_interfaces.cd5_template import CD5Template
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class CD5Templates(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     CD5Templates
                | 
                | Represents a List of all Templates from a Template type.
                | 
                | Example:
                | 
                |       The following example indicates how to retrieve the List of all
                |       Templates.
                |
                |      Dim oTemplates As ENOIACD5Templates
                |      Set oTemplates = oTemplateType.Templates
                |
                | See also:
                |     CD5TemplateType
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=CD5Template)
        self.cd5_templates = com_object

    def item(self, i_index: cat_variant) -> CD5Template:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As CD5Template
                | 
                |     Returns (gets) an item from the list of items.
                | 
                |     Example:
                | 
                |           The following example gets a Template at index 1.
                |
                |          Dim oTemplate As ENOIACD5Template
                |          Set oTemplate = oTemplates.Item(1)

        :param cat_variant i_index:
        :rtype: CD5Template
        """
        return CD5Template(self.cd5_templates.Item(i_index))

    def __repr__(self):
        return f'CD5Templates(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_image import AnalysisImage
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class AnalysisImages(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AnalysisImages
                | 
                | The collection of analysis images.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=AnalysisImage)
        self.analysis_images = com_object

    def add(
            self,
            i_image_name: str,
            i_hide_existing_images: cat_variant,
            i_show_mesh: cat_variant,
            i_duplicate: cat_variant) -> AnalysisImage:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(CATBSTR iImageName,
                | CATVariant iHideExistingImages,
                | CATVariant iShowMesh,
                | CATVariant iDuplicate) As AnalysisImage
                | 
                |     Creates a new image and adds it to the analysis image
                |     collection.
                | 
                |     Parameters:
                | 
                |         iImageName
                |             The name of the image to create. 
                |         iHideExistingImages
                |             To deactivate or not all the activated images before create the new
                |             image. 
                |         iShowMesh
                |             To show or not the mesh image. 
                |         iDuplicate
                |             To duplicate or not the new image, if same image already exists in
                |             collection of images. 
                | 
                |     Returns:
                |         The created Analysis Image 
                |     Example:
                | 
                |           This example create ThisAnalysisImage in the analysisImagesanalysis
                |           
                | 
                |          images collection. The image to create is supposed to be a mesh
                |          deformed image. 
                | 
                |          
                | 
                |          Dim ThisAnalysisImage As AnalysisImage
                |          Set ThisAnalysisImage = analysisImages.Add("Mesh_Deformed", True, False, False)

        :param str i_image_name:
        :param cat_variant i_hide_existing_images:
        :param cat_variant i_show_mesh:
        :param cat_variant i_duplicate:
        :rtype: AnalysisImage
        """
        return AnalysisImage(
            self.analysis_images.Add(
                i_image_name,
                i_hide_existing_images,
                i_show_mesh,
                i_duplicate
            )
        )

    def item(self, i_index: cat_variant) -> AnalysisImage:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As AnalysisImage
                | 
                |     Returns an analysis image using its index or its name from the analysis
                |     images collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the analysis image to retrieve from the
                |             collection of analysis images. This index is the rank of the analysis image in
                |             the collection. The index of the first analysis image in the collection is 1,
                |             and the index of the last analysis image is Count.
                |             
                | 
                |     Returns:
                |         The retrieved analysis image 
                |     Example:
                | 
                |           This example retrieves in ThisAnalysisImage the third analysis
                |           image.
                |          
                | 
                |          Dim ThisAnalysisImage As AnalysisImage
                |          Set ThisAnalysisImage = analysisImages.Item(3)

        :param cat_variant i_index:
        :rtype: AnalysisImage
        """
        return AnalysisImage(self.analysis_images.Item(i_index))

    def remove_image(self, i_image_identifier: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveImage(CATVariant iImageIdentifier)
                | 
                |     Deletes the Analysis Image from the analysis images collection of the
                |     Analysis Set.
                | 
                |     Parameters:
                | 
                |         iImageIdentifier
                |             The index or the name of the analysis image to delete from the
                |             Analysis Set. Note: The index given is the position of the image in the
                |             Analysis Set. Note: The name given is the string got from analysisImage.Name If
                |             the index or the name specified is not present in the Analysis Set, this method
                |             FAILS. The index of the first analysis image in the collection is 1, and the
                |             index of the last analysis image is Count. 
                | 
                |     Example:
                | 
                |           Example 1
                |          In this example analysisImages1 is the Analysis Set and analysisImage1
                |          is the image present in it.
                |          imageName = analysisImage1.Name
                |          analysisImages1.RemoveImage(imageName)
                |          
                |          Example 2
                |          analysisImages1.RemoveImage(4)
                |          In this example 4 is the index of the Image to be deleted in Analysis
                |          Set: analysisImages1

        :param cat_variant i_image_identifier:
        :rtype: None
        """
        return self.analysis_images.RemoveImage(i_image_identifier)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_image'
        # # vba_code = """
        # # Public Function remove_image(analysis_images)
        # #     Dim iImageIdentifier (2)
        # #     analysis_images.RemoveImage iImageIdentifier
        # #     remove_image = iImageIdentifier
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisImages(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swk_line_of_sight import SWKLineOfSight
from pycatia.dnb_human_modeling_interfaces.swk_manikin_part import SWKManikinPart


class SWKVision(SWKManikinPart):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBHumanModelingInterfaces.SWKManikinPart
                |                         SWKVision
                | 
                | This interface manages the vision of the manikin.
                | It provides
                | access to the vision data (lines of sight, focal point...)
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_vision = com_object

    @property
    def active_line_of_sight(self) -> SWKLineOfSight:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveLineOfSight() As SWKLineOfSight (Read Only)
                | 
                |     Returns the active line of sight, according to the vision type.

        :rtype: SWKLineOfSight
        """

        return SWKLineOfSight(self.swk_vision.ActiveLineOfSight)

    @property
    def active_side(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveSide() As long (Read Only)
                | 
                |     Returns the vision active side.
                |     The active line of sight is the one able to
                |     control the two others. That is, when the active line of
                |     sight moves, the two others update accordingly.
                |     When setting the type, the value given must be 0, 1 or 2.
                |     The value 0 activates the left line of sight, the value 1
                |     activates the central line of sight, the value 2 activates
                |     the right line of sight.
                |     If other values are given, an error will occur.

        :rtype: int
        """

        return self.swk_vision.ActiveSide

    @property
    def ambinocular_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AmbinocularAngle() As double
                | 
                |     Returns or sets the vision Ambinocular angle.
                |     This angle is always in degrees.

        :rtype: float
        """

        return self.swk_vision.AmbinocularAngle

    @ambinocular_angle.setter
    def ambinocular_angle(self, value: float):
        """
        :param float value:
        """

        self.swk_vision.AmbinocularAngle = value

    @property
    def binocular_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BinocularAngle() As double
                | 
                |     Returns or sets the vision Binocular angle.
                |     This angle is always in degrees.

        :rtype: float
        """

        return self.swk_vision.BinocularAngle

    @binocular_angle.setter
    def binocular_angle(self, value: float):
        """
        :param float value:
        """

        self.swk_vision.BinocularAngle = value

    @property
    def central_cone_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CentralConeAngle() As double
                | 
                |     Returns or sets the vision Central cone angle.
                |     This angle is always in degrees.

        :rtype: float
        """

        return self.swk_vision.CentralConeAngle

    @central_cone_angle.setter
    def central_cone_angle(self, value: float):
        """
        :param float value:
        """

        self.swk_vision.CentralConeAngle = value

    @property
    def focal_distance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FocalDistance() As double
                | 
                |     Returns or sets the focal distance, in centimeters.
                |     N.B.: if the value is -1.0,
                |     then the focal distance is set to infinite.

        :rtype: float
        """

        return self.swk_vision.FocalDistance

    @focal_distance.setter
    def focal_distance(self, value: float):
        """
        :param float value:
        """

        self.swk_vision.FocalDistance = value

    @property
    def focal_point_x(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FocalPointX() As double (Read Only)
                | 
                |     Returns the x coordinate (in millimeters) of the focal point.

        :rtype: float
        """

        return self.swk_vision.FocalPointX

    @property
    def focal_point_y(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FocalPointY() As double (Read Only)
                | 
                |     Returns the y coordinate (in millimeters) of the focal point.

        :rtype: float
        """

        return self.swk_vision.FocalPointY

    @property
    def focal_point_z(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FocalPointZ() As double (Read Only)
                | 
                |     Returns the z coordinate (in millimeters) of the focal point.

        :rtype: float
        """

        return self.swk_vision.FocalPointZ

    @property
    def monocular_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MonocularAngle() As double
                | 
                |     Returns or sets the vision Monocular angle.
                |     This angle is always in degrees.

        :rtype: float
        """

        return self.swk_vision.MonocularAngle

    @monocular_angle.setter
    def monocular_angle(self, value: float):
        """
        :param float value:
        """

        self.swk_vision.MonocularAngle = value

    @property
    def ponctum_proximum(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PonctumProximum() As double
                | 
                |     Returns or sets the ponctum proximum, in centimeters. The ponctum proximum
                |     is the minimum value the focal distance can take.

        :rtype: float
        """

        return self.swk_vision.PonctumProximum

    @ponctum_proximum.setter
    def ponctum_proximum(self, value: float):
        """
        :param float value:
        """

        self.swk_vision.PonctumProximum = value

    @property
    def ponctum_remotum(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PonctumRemotum() As double
                | 
                |     Returns or sets the ponctum remotum, in centimeters. The ponctum remotum is
                |     the largest value that the focal distance can take. N.B.: if the value is -1.0,
                |     then the ponctum remotum is set to infinite.

        :rtype: float
        """

        return self.swk_vision.PonctumRemotum

    @ponctum_remotum.setter
    def ponctum_remotum(self, value: float):
        """
        :param float value:
        """

        self.swk_vision.PonctumRemotum = value

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As long
                | 
                |     Returns or sets the vision type. (binocular, ambinocular, monocular left,
                |     monocular right or stereo.
                |     When setting the type, the value given must be 0, 1, 2, 3, or 4
                |     The value 0 activates the Binocular type, 1 is Ambinocular, 2 is
                |     MonocularRight, 3 is MonocularLeft, and 4 is Stereo. If other values are given,
                |     an error will occur.

        :rtype: int
        """

        return self.swk_vision.Type

    @type.setter
    def type(self, value: int):
        """
        :param int value:
        """

        self.swk_vision.Type = value

    @property
    def vertical_bottom_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VerticalBottomAngle() As double
                | 
                |     Returns or sets the vision Vertical Bottom angle.
                |     This angle is always in degrees.

        :rtype: float
        """

        return self.swk_vision.VerticalBottomAngle

    @vertical_bottom_angle.setter
    def vertical_bottom_angle(self, value: float):
        """
        :param float value:
        """

        self.swk_vision.VerticalBottomAngle = value

    @property
    def vertical_top_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VerticalTopAngle() As double
                | 
                |     Returns or sets the vision Vertical Top angle.
                |     This angle is always in degrees.

        :rtype: float
        """

        return self.swk_vision.VerticalTopAngle

    @vertical_top_angle.setter
    def vertical_top_angle(self, value: float):
        """
        :param float value:
        """

        self.swk_vision.VerticalTopAngle = value

    def close_vision_windows(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CloseVisionWindows()
                | 
                |     Closes all open vision windows relating to the manikin on which the
                |     function is called.

        :rtype: None
        """
        return self.swk_vision.CloseVisionWindows()

    def look_at(self, pi_focal_distance: float, pi_v_angle: float, pi_h_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LookAt(double piFocalDistance,
                | double piVAngle,
                | double piHAngle)
                | 
                |     Make the manikin look at the specified position in space.
                |     This position is given by the focal distance, and two
                |     deviation angles.
                | 
                |     Parameters:
                | 
                |         piFocalDistance
                |             The focal distance (measured from the active eye), which is a
                |             horizontal straight distance, measured in centimeters.
                |             
                |         piVAngle
                |             The vertical angle (in radians) between the focal point
                |             and
                |             the active eye (positive angle deviates up, negative angle deviates
                |             down). 
                |         piHAngle
                |             The horizontal angle (in radians) between the
                |             focal
                |             point and the active eye (positive angle deviates left, negative
                |             angle deviates right). N.B.: the manikin's eyes will move only if it is
                |             able
                |             to reach the specified point.

        :param float pi_focal_distance:
        :param float pi_v_angle:
        :param float pi_h_angle:
        :rtype: None
        """
        return self.swk_vision.LookAt(pi_focal_distance, pi_v_angle, pi_h_angle)

    def look_at_point(self, pi_x: float, pi_y: float, pi_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LookAtPoint(double piX,
                | double piY,
                | double piZ)
                | 
                |     Make the manikin look at the specified position in space.
                |     This position is given by three coordinates (expressed in
                |     millimeters)
                |     passed to the method.
                | 
                |     N.B.: the manikin's eyes will move only if it is able
                |     to reach the specified point.

        :param float pi_x:
        :param float pi_y:
        :param float pi_z:
        :rtype: None
        """
        return self.swk_vision.LookAtPoint(pi_x, pi_y, pi_z)

    def reset(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Reset()
                | 
                |     Resets all attributes of the vision to their default values. This method
                |     resets the focal distance, the active line of sight, the ponctum proximum, the
                |     ponctum remotum, the field of view angles, the convergence mode, and restores
                |     the default DOF values on the three lines of sight.

        :rtype: None
        """
        return self.swk_vision.Reset()

    def __repr__(self):
        return f'SWKVision(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class DimensionLimit(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DimensionLimit
                | 
                | Represents the limit object of tolerance dimensions.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dimension_limit = com_object

    @property
    def dimension_limit_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DimensionLimitType() As CATBSTR
                | 
                |     Returns or sets the dimension limit type.
                |     Legal values: Valid dimension limit type values are:
                | 
                |         CATTPSDLNotDefined
                |         CATTPSDLNumerical
                |         CATTPSDLTabulated
                |         CATTPSDLSingleLimit

        :rtype: str
        """

        return self.dimension_limit.DimensionLimitType

    @dimension_limit_type.setter
    def dimension_limit_type(self, value: str):
        """
        :param str value:
        """

        self.dimension_limit.DimensionLimitType = value

    @property
    def modifier(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Modifier() As CATBSTR
                | 
                |     Returns or sets the dimension single limit modifier.

        :rtype: str
        """

        return self.dimension_limit.Modifier

    @modifier.setter
    def modifier(self, value: str):
        """
        :param str value:
        """

        self.dimension_limit.Modifier = value

    @property
    def nominal_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Nominalvalue() As double (Read Only)
                | 
                |     Returns the dimension limit nominal value.
                |     This value is expressed in millimeters.

        :rtype: float
        """

        return self.dimension_limit.Nominalvalue

    @property
    def symetric_value(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SymetricValue() As boolean
                | 
                |     Returns or sets whether the dimension limit is symmetric.
                |     TRUE if it is symmetric.

        :rtype: bool
        """

        return self.dimension_limit.SymetricValue

    @symetric_value.setter
    def symetric_value(self, value: bool):
        """
        :param bool value:
        """

        self.dimension_limit.SymetricValue = value

    @property
    def tabulated_limit(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TabulatedLimit() As CATBSTR
                | 
                |     Returns or sets the dimension tabulated limit.
                |     This tabulated limit is expressed as a string.

        :rtype: str
        """

        return self.dimension_limit.TabulatedLimit

    @tabulated_limit.setter
    def tabulated_limit(self, value: str):
        """
        :param str value:
        """

        self.dimension_limit.TabulatedLimit = value

    def limits(self, o_bottom: float, o_up: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Limits(double oBottom,
                | double oUp)
                | 
                |     Retrieves dimension limit values.
                |     These values are expressed in millimeters.
                | 
                |     Parameters:
                | 
                |         oBottom
                |             The dimension limit bottom value 
                |         oUp
                |             The dimension limit up value

        :param float o_bottom:
        :param float o_up:
        :rtype: None
        """
        return self.dimension_limit.Limits(o_bottom, o_up)

    def put_limits(self, i_bottom: float, i_up: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutLimits(double iBottom,
                | double iUp)
                | 
                |     Sets dimension limit values.
                |     These values are expressed in millimeters.
                | 
                |     Parameters:
                | 
                |         iBottom
                |             The dimension limit bottom value 
                |         iUp
                |             The dimension limit up value

        :param float i_bottom:
        :param float i_up:
        :rtype: None
        """
        return self.dimension_limit.PutLimits(i_bottom, i_up)

    def __repr__(self):
        return f'DimensionLimit(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeLawDistProj(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeLawDistProj
                | 
                | Interface to law feature.
                | Role: Allows you to access data of a law feature created by using a reference
                | line and a definition curve.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_law_dist_proj = com_object

    @property
    def applied_unit_symbol(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AppliedUnitSymbol(CATBSTR iSymbol) (Write Only)
                | 
                |     Returns or sets the applied unit symbol for heterogeneous law.

        :rtype: str
        """

        return self.hybrid_shape_law_dist_proj.AppliedUnitSymbol

    @applied_unit_symbol.setter
    def applied_unit_symbol(self, value: str):
        """
        :param str value:
        """

        self.hybrid_shape_law_dist_proj.AppliedUnitSymbol = value

    @property
    def definition(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Definition() As Reference
                | 
                |     Returns or sets the definition curve of the law.
                |     Sub-element(s) supported (see Boundary object): see TriDimFeatEdge or
                |     BiDimFeatEdge.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_law_dist_proj.Definition)

    @definition.setter
    def definition(self, reference_definition: Reference):
        """
        :param Reference reference_definition:
        """

        self.hybrid_shape_law_dist_proj.Definition = reference_definition.com_object

    @property
    def measure_unit_symbol(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MeasureUnitSymbol(CATBSTR iSymbol) (Write Only)
                | 
                |     Returns or sets the measure unit symbol for heterogeneous law.

        :rtype: str
        """

        return self.hybrid_shape_law_dist_proj.MeasureUnitSymbol()

    @measure_unit_symbol.setter
    def measure_unit_symbol(self, value: str):
        """
        :param str value:
        """

        self.hybrid_shape_law_dist_proj.MeasureUnitSymbol = value

    @property
    def parameter_on_definition(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ParameterOnDefinition() As boolean
                | 
                |     Queries whether evolution parameter is on reference curve (default) or on definition curve,or
                |     sets evolution parameter on reference curve or on definition curve.
                |     Possible values of ParameterOnDefinition = TRUE : Parameter on definition curve. =
                |     FALSE : Parameter on reference curve.
                | 
                | Example:
                |     This example retrieves in ParOnDef the ParameterOnDefinition status of the
                |     hybridShapeLawDist hybrid shape law feature.
                | 
                |      Dim ParOnDef As boolean
                |      ParOnDef = hybridShapeLawDist.ParameterOnDefinition

        :rtype: bool
        """

        return self.hybrid_shape_law_dist_proj.ParameterOnDefinition

    @parameter_on_definition.setter
    def parameter_on_definition(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_law_dist_proj.ParameterOnDefinition = value

    @property
    def positive_direction_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PositiveDirectionOrientation() As long
                | 
                |     Returns or sets the positive value direction.

        :rtype: int
        """

        return self.hybrid_shape_law_dist_proj.PositiveDirectionOrientation

    @positive_direction_orientation.setter
    def positive_direction_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_law_dist_proj.PositiveDirectionOrientation = value

    @property
    def reference(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Reference() As Reference
                | 
                |     Returns or sets the reference line of the law.
                |     Sub-element(s) supported (see Boundary object): see
                |     RectilinearTriDimFeatEdge or RectilinearBiDimFeatEdge.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_law_dist_proj.Reference)

    @reference.setter
    def reference(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.hybrid_shape_law_dist_proj.Reference = reference.com_object

    @property
    def scaling(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Scaling() As double
                | 
                |     Returns or sets the scaling ratio of the law.

        :rtype: float
        """

        return self.hybrid_shape_law_dist_proj.Scaling

    @scaling.setter
    def scaling(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_law_dist_proj.Scaling = value

    def get_applied_unit_symbol(self, o_symbol: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetAppliedUnitSymbol(CATBSTR oSymbol)
                | 
                |     Returns the applied unit symbol.
                | 
                |     Parameters:
                | 
                |         oSymbol
                |             The symbol of applied unit 
                | 
                |     Example:
                |         This example retrieves in oSymbol the applied unit symbol of the
                |         hybridShapeLawDist hybrid shape law feature.
                | 
                |          Dim oSymbol
                |          hybridShapeLawDist.GetAppliedUnitSymboloSymbol

        :param str o_symbol:
        :rtype: None
        """
        return self.hybrid_shape_law_dist_proj.GetAppliedUnitSymbol(o_symbol)

    def get_measure_unit_symbol(self, o_symbol: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetMeasureUnitSymbol(CATBSTR oSymbol)
                | 
                |     Returns the measure unit symbol.
                | 
                |     Parameters:
                | 
                |         oSymbol
                |             The symbol of measure unit 
                | 
                |     Example:
                |         This example retrieves in oSymbol the measure unit symbol of the
                |         hybridShapeLawDist hybrid shape law feature.
                | 
                |          Dim oSymbol
                |          hybridShapeLawDist.GetMeasureUnitSymboloSymbol

        :param str o_symbol:
        :rtype: None
        """
        return self.hybrid_shape_law_dist_proj.GetMeasureUnitSymbol(o_symbol)

    def get_plane_normal(self, o_normal: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPlaneNormal(CATSafeArrayVariant oNormal)
                | 
                |     Retrieves the support plane normal.
                | 
                |     Parameters:
                | 
                |         oNormal
                |             The support plane normal

        :param tuple o_normal:
        :rtype: None
        """
        return self.hybrid_shape_law_dist_proj.GetPlaneNormal(o_normal)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_plane_normal'
        # # vba_code = """
        # # Public Function get_plane_normal(hybrid_shape_law_dist_proj)
        # #     Dim oNormal (2)
        # #     hybrid_shape_law_dist_proj.GetPlaneNormal oNormal
        # #     get_plane_normal = oNormal
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_heterogeneous_law(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func IsHeterogeneousLaw() As boolean
                | 
                |     Queries whether Heterogeneous Law mode is active or not.
                | 
                |     Parameters:
                | 
                |         oHeterogeneousLaw
                |             heterogeneous law mode = TRUE : Heterogeneous Law mode is active. =
                |             FALSE : Heterogeneous Law mode is inactive.

        :rtype: bool
        """
        return self.hybrid_shape_law_dist_proj.IsHeterogeneousLaw()

    def put_plane_normal(self, i_normal: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutPlaneNormal(CATSafeArrayVariant iNormal)
                | 
                |     Sets the support plane normal.
                | 
                |     Parameters:
                | 
                |         iNormal
                |             The support plane normal

        :param tuple i_normal:
        :rtype: None
        """
        return self.hybrid_shape_law_dist_proj.PutPlaneNormal(i_normal)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_plane_normal'
        # # vba_code = """
        # # Public Function put_plane_normal(hybrid_shape_law_dist_proj)
        # #     Dim iNormal (2)
        # #     hybrid_shape_law_dist_proj.PutPlaneNormal iNormal
        # #     put_plane_normal = iNormal
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeLawDistProj(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class HtsCCPSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         HtsCCPSettingAtt

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hts_ccp_setting_att = com_object

    @property
    def automatized_ccp(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AutomatizedCCP() As short
                | 
                |     Returns or sets the AutoCCP parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_ccp_setting_att.AutomatizedCCP

    @automatized_ccp.setter
    def automatized_ccp(self, value: int):
        """
        :param int value:
        """

        self.hts_ccp_setting_att.AutomatizedCCP = value

    @property
    def compass_pos(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CompassPos() As short
                | 
                |     Returns or sets the CompassPos parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_ccp_setting_att.CompassPos

    @compass_pos.setter
    def compass_pos(self, value: int):
        """
        :param int value:
        """

        self.hts_ccp_setting_att.CompassPos = value

    @property
    def current_pos(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CurrentPos() As short
                | 
                |     Returns or sets the CurrentPos parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_ccp_setting_att.CurrentPos

    @current_pos.setter
    def current_pos(self, value: int):
        """
        :param int value:
        """

        self.hts_ccp_setting_att.CurrentPos = value

    @property
    def first_act(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FirstAct() As short
                | 
                |     Returns or sets the FirstAct parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_ccp_setting_att.FirstAct

    @first_act.setter
    def first_act(self, value: int):
        """
        :param int value:
        """

        self.hts_ccp_setting_att.FirstAct = value

    @property
    def last_act(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LastAct() As short
                | 
                |     Returns or sets the LastAct parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_ccp_setting_att.LastAct

    @last_act.setter
    def last_act(self, value: int):
        """
        :param int value:
        """

        self.hts_ccp_setting_att.LastAct = value

    def get_auto_ccp_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAutoCCPInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AutoCCP
                |     parameter.
                |     Role:Retrieves the state of the AutoCCP parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_ccp_setting_att.GetAutoCCPInfo(io_admin_level, io_locked)

    def get_compass_pos_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCompassPosInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the CompassPos
                |     parameter.
                |     Role:Retrieves the state of the CompassPos parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_ccp_setting_att.GetCompassPosInfo(io_admin_level, io_locked)

    def get_current_pos_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCurrentPosInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the CurrentPos
                |     parameter.
                |     Role:Retrieves the state of the CurrentPos parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_ccp_setting_att.GetCurrentPosInfo(io_admin_level, io_locked)

    def get_first_act_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFirstActInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the FirstAct
                |     parameter.
                |     Role:Retrieves the state of the FirstAct parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_ccp_setting_att.GetFirstActInfo(io_admin_level, io_locked)

    def get_last_act_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLastActInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LastAct
                |     parameter.
                |     Role:Retrieves the state of the LastAct parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_ccp_setting_att.GetLastActInfo(io_admin_level, io_locked)

    def set_auto_ccp_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAutoCCPLock(boolean iLocked)
                | 
                |     Locks or unlocks the AutoCCP parameter.
                |     Role:Locks or unlocks the AutoCCP parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_ccp_setting_att.SetAutoCCPLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_auto_ccp_lock'
        # # vba_code = """
        # # Public Function set_auto_ccp_lock(hts_ccp_setting_att)
        # #     Dim iLocked (2)
        # #     hts_ccp_setting_att.SetAutoCCPLock iLocked
        # #     set_auto_ccp_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_compass_pos_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCompassPosLock(boolean iLocked)
                | 
                |     Locks or unlocks the CompassPos parameter.
                |     Role:Locks or unlocks the CompassPos parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_ccp_setting_att.SetCompassPosLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_compass_pos_lock'
        # # vba_code = """
        # # Public Function set_compass_pos_lock(hts_ccp_setting_att)
        # #     Dim iLocked (2)
        # #     hts_ccp_setting_att.SetCompassPosLock iLocked
        # #     set_compass_pos_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_current_pos_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCurrentPosLock(boolean iLocked)
                | 
                |     Locks or unlocks the CurrentPos parameter.
                |     Role:Locks or unlocks the CurrentPos parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_ccp_setting_att.SetCurrentPosLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_current_pos_lock'
        # # vba_code = """
        # # Public Function set_current_pos_lock(hts_ccp_setting_att)
        # #     Dim iLocked (2)
        # #     hts_ccp_setting_att.SetCurrentPosLock iLocked
        # #     set_current_pos_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_first_act_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetFirstActLock(boolean iLocked)
                | 
                |     Locks or unlocks the FirstAct parameter.
                |     Role:Locks or unlocks the FirstAct parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_ccp_setting_att.SetFirstActLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_first_act_lock'
        # # vba_code = """
        # # Public Function set_first_act_lock(hts_ccp_setting_att)
        # #     Dim iLocked (2)
        # #     hts_ccp_setting_att.SetFirstActLock iLocked
        # #     set_first_act_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_last_act_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLastActLock(boolean iLocked)
                | 
                |     Locks or unlocks the LastAct parameter.
                |     Role:Locks or unlocks the LastAct parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_ccp_setting_att.SetLastActLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_last_act_lock'
        # # vba_code = """
        # # Public Function set_last_act_lock(hts_ccp_setting_att)
        # #     Dim iLocked (2)
        # #     hts_ccp_setting_att.SetLastActLock iLocked
        # #     set_last_act_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HtsCcpSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchGapDisplay(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchGapDisplay
                | 
                | Manage the graphical representation of a schematic route.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_gap_display = com_object

    def is_gap_shown(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsGapShown(boolean oBYes)
                | 
                |     Query whether gaps are shown (gap attributes exist).
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then gaps are shown (gap attributes exist). If FALSE, then
                |             gaps are not shown (gap attributes do not exist). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGapDisplay
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.IsGapShownbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_gap_display.IsGapShown(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_gap_shown'
        # # vba_code = """
        # # Public Function is_gap_shown(sch_gap_display)
        # #     Dim oBYes (2)
        # #     sch_gap_display.IsGapShown oBYes
        # #     is_gap_shown = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_gap(self, i_luk_routes: SchListOfObjects) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGap(SchListOfObjects iLUKRoutes)
                | 
                |     Add gap display attributes on the route.
                | 
                |     Parameters:
                | 
                |         iLUKRoutes
                |             A list of routes to be processed, default is NULL (if NULL, then
                |             all routes in model are processed). Members are CATISchRoute interface
                |             pointers. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchGapDisplay
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          objThisIntf.SetGapobjArg1

        :param SchListOfObjects i_luk_routes:
        :rtype: None
        """
        return self.sch_gap_display.SetGap(i_luk_routes.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_gap'
        # # vba_code = """
        # # Public Function set_gap(sch_gap_display)
        # #     Dim iLUKRoutes (2)
        # #     sch_gap_display.SetGap iLUKRoutes
        # #     set_gap = iLUKRoutes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def unset_gap(self, i_luk_routes: SchListOfObjects) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnsetGap(SchListOfObjects iLUKRoutes)
                | 
                |     Remove gap display attributes on the route. A list of routes to be
                |     processed, default is NULL (if NULL, then all routes in model are processed).
                |     Members are CATISchRoute interface pointers.
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGapDisplay
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          objThisIntf.UnsetGapobjArg1

        :param SchListOfObjects i_luk_routes:
        :rtype: None
        """
        return self.sch_gap_display.UnsetGap(i_luk_routes.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'unset_gap'
        # # vba_code = """
        # # Public Function unset_gap(sch_gap_display)
        # #     Dim iLUKRoutes (2)
        # #     sch_gap_display.UnsetGap iLUKRoutes
        # #     unset_gap = iLUKRoutes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchGapDisplay(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.ppr_interfaces.ppr_products import PPRProducts


class PPRActivity(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         PPRActivity
                | 
                | The interface is used to retrieve the items and resources of the current
                | Activity.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.ppr_activity = com_object

    @property
    def ppr_items(self) -> PPRProducts:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PPRItems() As PPRProducts (Read Only)
                | 
                |     Retrieves the list of items as Products aggregated by the
                |     Activity.
                | 
                |     Returns:
                |         The list of items of the current Activity.

        :rtype: PPRProducts
        """

        return PPRProducts(self.ppr_activity.PPRItems)

    @property
    def ppr_items_and_fta(self) -> list:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PPRItemsAndFTA() As CATIAPPRItems (Read Only)
                | 
                |     Retrieves the list of items as CATIAItems aggregated by the
                |     Activity.
                | 
                |     Returns:
                |         The list of items of the current Activity, including ASMPRODUCT and
                |         possibly FTA objects

        :rtype: list
        """

        return self.ppr_activity.PPRItemsAndFTA

    @property
    def ppr_resources(self) -> PPRProducts:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PPRResources() As PPRProducts (Read Only)
                | 
                |     Retrieves the list of resources as Products aggregated by the
                |     Activity.
                | 
                |     Returns:
                |         The list of resources of the current Activity.

        :rtype: PPRProducts
        """

        return PPRProducts(self.ppr_activity.PPRResources)

    def __repr__(self):
        return f'PprActivity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ExpertRuleBaseComponentRuntime(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ExpertRuleBaseComponentRuntime
                | 
                | Represents a rule base component in a ruleset.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.expert_rule_base_component_runtime = com_object

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Comment() As CATBSTR
                | 
                |     Returns or sets the comment of a rulebase component.

        :rtype: str
        """

        return self.expert_rule_base_component_runtime.Comment

    @comment.setter
    def comment(self, value: str):
        """
        :param str value:
        """

        self.expert_rule_base_component_runtime.Comment = value

    def accurate_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AccurateType() As CATBSTR
                | 
                |     Returns as a string the type of component. Returns a string among
                |     ("ExpertCheck", "ExpertCheckRuntime", "ExpertRule", "ExpertRuleRuntime",
                |     "ExpertRuleSet", "ExpertRuleSetRuntime").
                | 
                |     Returns:
                |         Type name of the rule base component

        :rtype: str
        """
        return self.expert_rule_base_component_runtime.AccurateType()

    def activate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Activate()
                | 
                |     Activates the RuleBaseComponent.
                | 
                |     Example:
                |         This example activates the SolidActivity ExpertCheck:
                | 
                |          Dim CATDocs As Document
                |          Set CATDocs   = CATIA.Documents
                |          Dim partdoc As PartDocument
                |          Set partdoc   = CATDocs.Add("CATPart")
                |          Dim part As Part
                |          Set part      = partdoc.Part
                |          part.Relations.Item("RuleBase").RuleSet.ExpertRuleBaseComponentRuntimes.Item("SolidActivity").Activate()

        :rtype: None
        """
        return self.expert_rule_base_component_runtime.Activate()

    def deactivate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Deactivate()
                | 
                |     Desactivates the RuleBaseComponent.
                | 
                |     Example:
                |         This example Desactivates the SolidActivity
                |         ExpertCheck:
                | 
                |          Dim CATDocs As Document
                |          Set CATDocs   = CATIA.Documents
                |          Dim partdoc As PartDocument
                |          Set partdoc   = CATDocs.Add("CATPart")
                |          Dim part As Part
                |          Set part      = partdoc.Part
                |          part.Relations.Item("RuleBase").RuleSet.ExpertRuleBaseComponentRuntimes.Item("SolidActivity").Deactivate()

        :rtype: None
        """
        return self.expert_rule_base_component_runtime.Deactivate()

    def is_use_only(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsUseOnly() As boolean
                | 
                |     Retrieves the use-only status of the component.
                | 
                |     Returns:
                |         Use only status of the component

        :rtype: bool
        """
        return self.expert_rule_base_component_runtime.IsUseOnly()

    def is_activate(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Isactivate() As boolean
                | 
                |     Tells if the RuleBaseComponent is active.
                | 
                |     Example:
                |         This example tells if the SolidActivity ExpertCheck is active
                |         :
                | 
                |          Dim CATDocs As Document
                |          Set CATDocs   = CATIA.Documents
                |          Dim partdoc As PartDocument
                |          Set partdoc   = CATDocs.Add("CATPart")
                |          Dim part As Part
                |          Set part      = partdoc.Part
                |          status = part.Relations.Item("RuleBase").RuleSet.ExpertRuleBaseComponentRuntimes.Item("SolidActivity").Isactivate()
                |          
                | 
                |     Returns:
                |         Activity of the rule base component

        :rtype: bool
        """
        return self.expert_rule_base_component_runtime.Isactivate()

    def parse(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Parse() As CATBSTR
                | 
                |     Syntactically analyses (ie parses) the component.
                | 
                |     Returns:
                |         Empty string if the parse is correct, otherwise comments on the errors

        :rtype: str
        """
        return self.expert_rule_base_component_runtime.Parse()

    def set_use_only(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUseOnly()
                | 
                |     Prevents any access to the component for reading or deleting.
                |     Be careful : this operation is not reversible.

        :rtype: None
        """
        return self.expert_rule_base_component_runtime.SetUseOnly()

    def __repr__(self):
        return f'ExpertRuleBaseComponentRuntime(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connectable import SchAppConnectable
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchAppZone(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppZone
                | 
                | Manage a schematic zone.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_zone = com_object

    def app_add_zone_member(self, i_app_cntbl_to_add: SchAppConnectable) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppAddZoneMember(SchAppConnectable iAppCntblToAdd)
                | 
                |     Add an application connectable object to the zone as
                |     member.
                | 
                |     Parameters:
                | 
                |         iAppCntblToAdd
                |             The application connectable object to be added to the zone.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchAppZone
                |          Dim objArg1 As SchAppConnectable
                |           ...
                |          objThisIntf.AppAddZoneMemberobjArg1

        :param SchAppConnectable i_app_cntbl_to_add:
        :rtype: None
        """
        return self.sch_app_zone.AppAddZoneMember(i_app_cntbl_to_add.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_add_zone_member'
        # # vba_code = """
        # # Public Function app_add_zone_member(sch_app_zone)
        # #     Dim iAppCntblToAdd (2)
        # #     sch_app_zone.AppAddZoneMember iAppCntblToAdd
        # #     app_add_zone_member = iAppCntblToAdd
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_list_zone_members(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppListZoneMembers() As SchListOfObjects
                | 
                |     List all members of an application zone.
                | 
                |     Parameters:
                | 
                |         oLAppCntbl
                |             A list of zone members (application connectables).
                |             
                |     Example:
                |
                |          Dim objThisIntf As SchAppZone
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.AppListZoneMembers

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_app_zone.AppListZoneMembers())

    def app_remove_zone_member(self, i_app_cntbl_to_remove: SchAppConnectable) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppRemoveZoneMember(SchAppConnectable
                | iAppCntblToRemove)
                | 
                |     Remove an application connectable object to the zone as
                |     member.
                | 
                |     Parameters:
                | 
                |         iAppCntblToRemove
                |             The application connectable object to be removed to the zone.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchAppZone
                |          Dim objArg1 As SchAppConnectable
                |           ...
                |          objThisIntf.AppRemoveZoneMemberobjArg1

        :param SchAppConnectable i_app_cntbl_to_remove:
        :rtype: None
        """
        return self.sch_app_zone.AppRemoveZoneMember(i_app_cntbl_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_remove_zone_member'
        # # vba_code = """
        # # Public Function app_remove_zone_member(sch_app_zone)
        # #     Dim iAppCntblToRemove (2)
        # #     sch_app_zone.AppRemoveZoneMember iAppCntblToRemove
        # #     app_remove_zone_member = iAppCntblToRemove
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppZone(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.body import Body
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication
from pycatia.system_interfaces.any_object import AnyObject


class ABQMassScaling(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQMassScaling
                | 
                | Represents an Abaqus Mass Scaling entity.
                | 
                | Role: Used to access the properties of a Mass Scaling entity.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_mass_scaling = com_object

    @property
    def frequency_increment(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FrequencyIncrement() As long
                | 
                |     Sets or returns the scaling frequency increment. Applies only when
                |     FrequencyType is ABQ_INCREMENT.

        :rtype: int
        """

        return self.abq_mass_scaling.FrequencyIncrement

    @frequency_increment.setter
    def frequency_increment(self, value: int):
        """
        :param int value:
        """

        self.abq_mass_scaling.FrequencyIncrement = value

    @property
    def frequency_interval(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FrequencyInterval() As long
                | 
                |     Sets or returns the scaling frequency interval. Applies only when
                |     FrequencyType is ABQ_INTERVAL.

        :rtype: int
        """

        return self.abq_mass_scaling.FrequencyInterval

    @frequency_interval.setter
    def frequency_interval(self, value: int):
        """
        :param int value:
        """

        self.abq_mass_scaling.FrequencyInterval = value

    @property
    def frequency_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FrequencyType() As AbqMsFrequencyType
                | 
                |     Sets or returns the scaling frequency type.

        :return: enum abq_ms_frequency_type
        :rtype: int
        """

        return self.abq_mass_scaling.FrequencyType

    @frequency_type.setter
    def frequency_type(self, value: int):
        """
        :param int value:
        """

        self.abq_mass_scaling.FrequencyType = value

    @property
    def global_(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Global() As boolean
                | 
                |     Sets or returns whether the mass scaling is global.

        :rtype: bool
        """

        return self.abq_mass_scaling.Global

    @global_.setter
    def global_(self, value: bool):
        """
        :param bool value:
        """

        self.abq_mass_scaling.Global = value

    @property
    def num_supports(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumSupports() As long (Read Only)
                | 
                |     Retrieves the number of supports.

        :rtype: int
        """

        return self.abq_mass_scaling.NumSupports

    @property
    def scale_factor(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ScaleFactor() As double
                | 
                |     Sets or returns the scale factor.

        :rtype: float
        """

        return self.abq_mass_scaling.ScaleFactor

    @scale_factor.setter
    def scale_factor(self, value: float):
        """
        :param float value:
        """

        self.abq_mass_scaling.ScaleFactor = value

    @property
    def scale_factor_on(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ScaleFactorOn() As boolean
                | 
                |     Sets or returns whether the scale factor is active.

        :rtype: bool
        """

        return self.abq_mass_scaling.ScaleFactorOn

    @scale_factor_on.setter
    def scale_factor_on(self, value: bool):
        """
        :param bool value:
        """

        self.abq_mass_scaling.ScaleFactorOn = value

    @property
    def target_method(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TargetMethod() As AbqMsTargetMethod
                | 
                |     Sets or returns the target time scaling method. Applies only when target
                |     time is active.

        :return: enum abq_ms_target_method
        :rtype: int
        """

        return self.abq_mass_scaling.TargetMethod

    @target_method.setter
    def target_method(self, value: int):
        """
        :param int value:
        """

        self.abq_mass_scaling.TargetMethod = value

    @property
    def target_time(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TargetTime() As double
                | 
                |     Sets or returns the scaling target time.

        :rtype: float
        """

        return self.abq_mass_scaling.TargetTime

    @target_time.setter
    def target_time(self, value: float):
        """
        :param float value:
        """

        self.abq_mass_scaling.TargetTime = value

    @property
    def target_time_on(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TargetTimeOn() As boolean
                | 
                |     Sets or returns whether the target time scaling is active.

        :rtype: bool
        """

        return self.abq_mass_scaling.TargetTimeOn

    @target_time_on.setter
    def target_time_on(self, value: bool):
        """
        :param bool value:
        """

        self.abq_mass_scaling.TargetTimeOn = value

    @property
    def variable(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Variable() As boolean
                | 
                |     Sets or returns whether the mass scaling is variable.

        :rtype: bool
        """

        return self.abq_mass_scaling.Variable

    @variable.setter
    def variable(self, value: bool):
        """
        :param bool value:
        """

        self.abq_mass_scaling.Variable = value

    def add_support_for_body(self, i_product: Product, i_body: Body) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportForBody(Product iProduct,
                | Body iBody)
                | 
                |     Adds the specified body as a support.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIAProduct specifying the positioning object.
                |             
                |         iBody
                |             The CATIABody to serve as the support.
                |             Refer: CATIABody , CATIAProduct

        :param Product i_product:
        :param Body i_body:
        :rtype: None
        """
        return self.abq_mass_scaling.AddSupportForBody(i_product.com_object, i_body.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_for_body'
        # # vba_code = """
        # # Public Function add_support_for_body(abq_mass_scaling)
        # #     Dim iProduct (2)
        # #     abq_mass_scaling.AddSupportForBody iProduct
        # #     add_support_for_body = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_product(self, i_product: Product, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromProduct(Product iProduct,
                | Reference iSupport)
                | 
                |     Adds the specified product reference as a support. If the support already
                |     exists then it is removed.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIAProduct specifying the positioning object.
                |             
                |         iSupport
                |             The CATIAReference to serve as the support.

        :param Product i_product:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_mass_scaling.AddSupportFromProduct(i_product.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_product'
        # # vba_code = """
        # # Public Function add_support_from_product(abq_mass_scaling)
        # #     Dim iProduct (2)
        # #     abq_mass_scaling.AddSupportFromProduct iProduct
        # #     add_support_from_product = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Adds a support from the publication. If the support already exists, it is
                |     removed.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the mass scaling
                |             is applied.
                |         iPublication
                |             The CATIA Publication specifying the region to which the mass
                |             scaling is applied.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.abq_mass_scaling.AddSupportFromPublication(i_product.com_object, i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(abq_mass_scaling)
        # #     Dim iProduct (2)
        # #     abq_mass_scaling.AddSupportFromPublication iProduct
        # #     add_support_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def clear_supports(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ClearSupports()
                | 
                |     Clear the list of supports.

        :rtype: None
        """
        return self.abq_mass_scaling.ClearSupports()

    def get_supports(self, o_products: tuple, o_supports: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSupports(CATSafeArrayVariant oProducts,
                | CATSafeArrayVariant oSupports)
                | 
                |     Gets the supports that define the mass scaling region(s).
                | 
                |     Parameters:
                | 
                |         oProducts
                |             Returned safe array of products for the supports, as
                |             CATIAReferences. This array has a one-to-one mapping with the supports array.
                |             
                |         oSupports
                |             Returned safe array of supports, as CATIAReferences. This array has
                |             a one-to-one mapping with the products array.

        :param tuple o_products:
        :param tuple o_supports:
        :rtype: None
        """
        return self.abq_mass_scaling.GetSupports(o_products, o_supports)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_supports'
        # # vba_code = """
        # # Public Function get_supports(abq_mass_scaling)
        # #     Dim oProducts (2)
        # #     abq_mass_scaling.GetSupports oProducts
        # #     get_supports = oProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_supports(self, i_products: tuple, i_supports: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSupports(CATSafeArrayVariant iProducts,
                | CATSafeArrayVariant iSupports)
                | 
                |     Sets the supports that define the mass scaling region(s). Any previously
                |     set support regions will be replaced with this new list. The list must contain
                |     at least one item.
                | 
                |     Parameters:
                | 
                |         iProducts
                |             Safe array of products for the supports as CATIAReferences. This
                |             array has a one-to-one mapping with the supports array.
                |             
                |         iSupports
                |             Safe array of supports as CATIAReferences. This array has a
                |             one-to-one mapping with the products array.

        :param tuple i_products:
        :param tuple i_supports:
        :rtype: None
        """
        return self.abq_mass_scaling.SetSupports(i_products, i_supports)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_supports'
        # # vba_code = """
        # # Public Function set_supports(abq_mass_scaling)
        # #     Dim iProducts (2)
        # #     abq_mass_scaling.SetSupports iProducts
        # #     set_supports = iProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQMassScaling(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PCBHoleAndPattern(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PCBHoleAndPattern

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.pcb_hole_and_pattern = com_object

    @property
    def associated_part_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AssociatedPartName() As CATBSTR
                | 
                |     Allow to get and set the Associated Part of a hole
                |     The possible values are : the name of the instance of component in which the hole is defined.
                |     BOARD if the hole is defined in the Board part
                |     PANEL If the hole is defined in the Panel part
                |     NOREFDES is the hole is defined in a non Electronic Part.
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_hole_and_pattern.AssociatedPartName

    @associated_part_name.setter
    def associated_part_name(self, value: str):
        """
        :param str value:
        """

        self.pcb_hole_and_pattern.AssociatedPartName = value

    @property
    def hole_owner(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HoleOwner() As CATBSTR
                | 
                |     Allow to get and set the Operating power rating of a component The possible
                |     value are MCAD,ECAD, UNOWNED
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_hole_and_pattern.HoleOwner

    @hole_owner.setter
    def hole_owner(self, value: str):
        """
        :param str value:
        """

        self.pcb_hole_and_pattern.HoleOwner = value

    @property
    def hole_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HoleType() As CATBSTR
                | 
                |     Allow to get and set the function of the hole The different values are :
                |     PIN if the hole is associated with a component pin
                |     VIA if the hole is associated with a conductive via
                |     MTG if the hole is used for mounting purposes
                |     TOOL if the hole is used for tooling purposes Other ( User defined )
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_hole_and_pattern.HoleType

    @hole_type.setter
    def hole_type(self, value: str):
        """
        :param str value:
        """

        self.pcb_hole_and_pattern.HoleType = value

    @property
    def plating_style(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PlatingStyle() As CATBSTR
                | 
                |     Allow to get and set the Plating Style of a hole The possible values are : PTH, NPTH
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_hole_and_pattern.PlatingStyle

    @plating_style.setter
    def plating_style(self, value: str):
        """
        :param str value:
        """

        self.pcb_hole_and_pattern.PlatingStyle = value

    def __repr__(self):
        return f'PCBHoleAndPattern(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_objects import PSPListOfObjects
from pycatia.cat_plant_ship_interfaces.psp_part_connector import PSPPartConnector
from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.any_object import AnyObject


class PSPPhsyicalProduct(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspPhsyicalProduct
                | 
                | Represents the interface to manage the technological connectors on physical
                | objects.
                | Role: To manage connectors on physical objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_phsyical_product = com_object

    @property
    def connectors(self) -> PSPListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Connectors() As PspListOfObjects (Read Only)
                | 
                |     Returns a list of Part connectors of the object.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPhsyicalProduct  
                |          Dim objArg1 As PspListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.Connectors

        :rtype: PSPListOfObjects
        """

        return PSPListOfObjects(self.psp_phsyical_product.Connectors)

    def add_connector(
            self,
            i_class_filter: str,
            i_face_cntr: Reference,
            ie_face_type: int,
            i_alignment_cntr: Reference,
            ie_align_type: int,
            i_clock_cntr: Reference,
            ie_clock_type: int
    ) -> PSPPartConnector:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddConnector(CATBSTR iClassFilter,
                | Reference iFaceCntr,
                | CatPspIDLPartConnectorType ieFaceType,
                | Reference iAlignmentCntr,
                | CatPspIDLPartConnectorType ieAlignType,
                | Reference iClockCntr,
                | CatPspIDLPartConnectorType ieClockType) As PspPartConnector
                | 
                |     Returns the added connector on the object.
                | 
                |     Parameters:
                | 
                |         iuClassFilter
                |             Connector class type. If null string application default connector
                |             class will be used. 
                |         iFaceCntr
                |             A face connector 
                |         ieFaceType
                |             Face connector type 
                |         iAlignmentCntr
                |             An alignment connector 
                |         ieAlignType
                |             Alignment connector type 
                |         iClockCntr
                |             A clock connector 
                |         ieClockType
                |             A clock connector type 
                | 
                |     Returns:
                |         Part connector added
                |
                |     Example:
                |
                |          Dim objThisIntf As PspPhsyicalProduct
                |          Dim strVar1 As CATBSTR
                |          Dim objArg2 As Reference
                |          Dim objArg3 As catPspIDLPartConnectorType
                |          Dim objArg4 As Reference
                |          Dim objArg5 As catPspIDLPartConnectorType
                |          Dim objArg6 As Reference
                |          Dim objArg7 As catPspIDLPartConnectorType
                |          Dim objArg8 As PspPartConnector
                |           ...
                |          objArg8 = objThisIntf.AddConnector (strVar1, objArg2,objArg3,objArg4, objArg5,objArg6,objArg7 )

        :param str i_class_filter:
        :param Reference i_face_cntr:
        :param int ie_face_type: enum cat_psp_idl_part_connector_type
        :param Reference i_alignment_cntr:
        :param int ie_align_type: enum cat_psp_idl_part_connector_type
        :param Reference i_clock_cntr:
        :param int ie_clock_type: enum cat_psp_idl_part_connector_type
        :rtype: PSPPartConnector
        """
        return PSPPartConnector(
            self.psp_phsyical_product.AddConnector(
                i_class_filter,
                i_face_cntr.com_object,
                ie_face_type,
                i_alignment_cntr.com_object,
                ie_align_type,
                i_clock_cntr.com_object,
                ie_clock_type
            )
        )

    def remove_connector(self, i_cntr_to_remove: PSPPartConnector) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveConnector(PspPartConnector iCntrToRemove)
                | 
                |     Removes part connector.
                | 
                |     Parameters:
                | 
                |         iCntrToRemove
                |             Part connector to be removed 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPhsyicalProduct
                |          Dim objArg1 As PspPartConnector
                |           ...
                |          objThisIntf.RemoveConnector objArg1

        :param PSPPartConnector i_cntr_to_remove:
        :rtype: None
        """
        return self.psp_phsyical_product.RemoveConnector(i_cntr_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_connector'
        # # vba_code = """
        # # Public Function remove_connector(psp_phsyical_product)
        # #     Dim iCntrToRemove (2)
        # #     psp_phsyical_product.RemoveConnector iCntrToRemove
        # #     remove_connector = iCntrToRemove
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PSPPhsyicalProduct(name="{self.name}")'



from pathlib import Path

from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class SWKHumanCatalog(AnyObject):
    """
    This class is not documented in the CAA V5 Visual Basic Help file.

    This class was created by referring to the Microsoft Visual Basic object explorer.
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.com_object = com_object

    @property
    def active_family(self) -> str:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Property ActiveFamily As String
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :rtype: str
        """

        return self.com_object.ActiveFamily

    @property
    def is_dirty(self) -> bool:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Property IsDirty As Boolean
                |     read-only
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :rtype: bool
        """

        return self.com_object.IsDirty

    @property
    def nb_items(self) -> int:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Property NbItems As Long
                |     read-only
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :rtype: int
        """

        return self.com_object.NbItems

    @property
    def number_of_families(self) -> int:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Property NumberOfFamilies As Long
                |     read-only
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :rtype: int
        """

        return self.com_object.NumberOfFamilies

    def add_item_from_hso(self, pi_description: str) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub AddItemFromHSO(piDescription As String)
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :param str pi_description:
        :rtype: None
        """

        return self.com_object.AddItemFromHSO(pi_description)

    def add_items_from_swl_file(self, pi_file_path: Path) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub AddItemsFromSwlFile(piFilePath As String)
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :param Path pi_file_path:
        :rtype: None
        """

        return self.com_object.AddItemsFromSwlFile(pi_file_path)

    def apply_item(self, pi_index: int) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub ApplyItem(piIndex As Long)
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :param int pi_index:
        :rtype: None
        """

        return self.com_object.ApplyItem(pi_index)

    def empty(self) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub Empty()
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :rtype: None
        """

        return self.com_object.Empty()

    def get_attach_and_cst_infos(self) -> cat_variant:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub GetAttachAndCstInfos(piIndex As Long, piNbInfos As Long, poInfos() As Variant)
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :rtype: cat_variant
        """

        return self.com_object.GetAttachAndCstInfos()

    def get_family_name(self, pi_index: int) -> str:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function GetFamilyName(piIndex As Long) As String
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :param int pi_index:
        :rtype: cat_variant
        """

        return self.com_object.GetFamilyName(pi_index)

    def get_item_date(self, pi_index: int) -> str:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function GetItemDate(piIndex As Long) As String
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :param int pi_index:
        :rtype: str
        """

        return self.com_object.GetItemDate(pi_index)

    def get_item_description(self, pi_index: int) -> str:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function GetItemDescription(piIndex As Long) As String
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :param int pi_index:
        :rtype: str
        """

        return self.com_object.GetItemDescription(pi_index)

    def get_item_type(self, pi_index: int) -> str:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function GetItemType(piIndex As Long) As String
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :param int pi_index:
        :rtype: str
        """

        return self.com_object.GetItemType(pi_index)

    def get_nb_attach_and_cst(self, pi_index: int) -> int:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function GetNbAttachAndCst(piIndex As Long) As Long
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :param int pi_index:
        :rtype: int
        """

        return self.com_object.GetNbAttachAndCst(pi_index)

    def reload(self) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub Reload()
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :rtype: None
        """

        return self.com_object.Reload()

    def remove_item(self, pi_index: int) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub RemoveItem(piIndex As Long)
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :param int pi_index:
        :rtype: None
        """

        return self.com_object.RemoveItem(pi_index)

    def save(self) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub Save()
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :rtype: None
        """

        return self.com_object.Save()

    def set_attach_or_cst_object(self, pi_description_index: int, pi_item_index: int, pi_reference: Reference) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub SetAttachOrCstObject(piDescriptionIndex As Long, piItemIndex As Long, piReference As Reference)
                |     Member of SWKHumanModelingItf.SWKHumanCatalog

        :param int pi_description_index:
        :param int pi_item_index:
        :param int pi_reference:
        :rtype: None
        """

        return self.com_object.SetAttachOrCstObject(pi_description_index, pi_item_index, pi_reference)



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document


class CatalogDocument(Document):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Document
                |                         CatalogDocument
                | 
                | Represents the Document object for catalog.
                | Role: A catalog document references data (documents: CATPart..., features, etc)
                | organized as a tree: the nodes are called chapters and the leaves are called
                | descriptions. Each description may reference a document (CATPart...) and
                | couples of keyword + value. The keywords are defined at the parent chapter
                | level.
                | A catalog may reference parametric Parts. In that case, the Part is associated
                | with a Design Table. A Design Table is a file (text file, Excel document) that
                | contains named columns and rows. Each row corresponds to a description, and
                | each column may correspond to a keyword.
                | Refer to CATIA V5 Documentation, Component Catalog Editor and to CAA V5
                | Encyclopedia, Document, Catalog.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.catalog_document = com_object

    def create_catalog_from_library(self,
                                    i_library_path: str,
                                    i_project_path: str,
                                    i_catalog_path: str,
                                    i_table_path: str,
                                    i_conv_format: int,
                                    i_batch_mode: int) -> 'CatalogDocument':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateCatalogFromLibrary(CATBSTR iLibraryPath,
                | CATBSTR iProjectPath,
                | CATBSTR iCatalogPath,
                | CATBSTR iTablePath,
                | short iConvFormat,
                | short iBatchMode)
                | 
                |     Creates a catalog from a V4 library.
                | 
                |     Parameters:
                | 
                |         iLibraryPath
                |             The V4 library path. 
                |         iProjectPath
                |             The V4 project path. 
                |         iCatalogPath
                |             The new catalog path. 
                |         iTablePath
                |             The mapping table path. 
                |         iConvFormat
                |             0: As Specification
                |             1: As Result 
                |         iBatchMode
                |             0: As Specification
                |             1: As Result 
                |         iBatchMode
                |             0: Create the V5 documents
                |             1: Simulate: the V5 documents are not created
                |             2: If the previous migration has failed, continue since this
                |             point.

        :param str i_library_path:
        :param str i_project_path:
        :param str i_catalog_path:
        :param str i_table_path:
        :param int i_conv_format:
        :param int i_batch_mode:
        :rtype: None
        """
        return CatalogDocument(
            self.catalog_document.CreateCatalogFromLibrary(
                i_library_path,
                i_project_path,
                i_catalog_path,
                i_table_path,
                i_conv_format,
                i_batch_mode).com_object)

    def create_catalog_from_csv(self, i_init_data: str, i_new_catalog: str) -> 'CatalogDocument':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateCatalogFromcsv(CATBSTR iInitData,
                | CATBSTR iNewCatalog)
                | 
                |     Creates a catalog from a csv file.
                |     Refer to CATIA V5 Documentation, Component Catalog Editor, Creating a
                |     Catalog in Batch Mode.
                | 
                |     Parameters:
                | 
                |         iInitData
                |             The csv (Comma Separated Values) file path. 
                |         iNewCatalog
                |             The new catalog path.
                | 
                |             Example:
                |                 This example creates a catalog from a csv
                |                 file.
                | 
                |                    InputFile = "E:\\users\\Catalogs\\BatchCatalog.csv"
                |                    OutputFile = "E:\\users\\Catalogs\\Catalog_Result.catalog"
                |                    Dim Catalog As Document
                |                    Set Catalog=CATIA.Documents.Add("CatalogDocument")
                |                    Catalog.CreateCatalogFromcsv InputFile,
                |                    OutputFile

        :param str i_init_data:
        :param str i_new_catalog:
        :return: None
        :rtype: CatalogDocument
        """
        return self.catalog_document.CreateCatalogFromcsv(i_init_data, i_new_catalog)

    def create_chapter_from_design_table(self, i_chapter_name: str, i_document_containing_dt: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateChapterFromDesignTable(CATBSTR iChapterName,
                | CATBSTR iDocumentContainingDT)
                | 
                |     Creates a chapter in the current catalog document where keywords correspond
                |     to parameters of the Design Table and add the descriptions corresponding to
                |     whole configurations of the Design Table.
                |     Refer to CATIA V5 Documentation, Component Catalog Editor, Creating a
                |     Catalog in Batch Mode.
                | 
                |     Parameters:
                | 
                |         iChapterName
                |             The name of the new chapter. 
                |         iDocumentContainingDT
                |             The path of the Design Table.
                | 
                |             Example:
                |                 This example creates a catalog and a chapter is added from a
                |                 Design Table.
                | 
                |                    Chapter = "NewChapter"
                |                    DTFile = "E:\\users\\Catalogs\\DesignTable.xls"
                |                    Dim Catalog As Document
                |                    Set Catalog=CATIA.Documents.Add("CatalogDocument")
                |                    Catalog.CreateChapterFromDesignTable Chapter,
                |                    DTFile

        :param str i_chapter_name:
        :param str i_document_containing_dt:
        :rtype: None
        """
        return self.catalog_document.CreateChapterFromDesignTable(i_chapter_name, i_document_containing_dt)

    def __repr__(self):
        return f'CatalogDocument(name="{ self.name }")'
